@@ -2,7 +2,7 @@
 
 cd ../fortran
 gfortran -E ompgen.F90 -cpp -o omp.f90
-f2py *.f90 -m _wrffortran -h wrffortran.pyf --overwrite-signature
+#f2py *.f90 -m _wrffortran -h wrffortran.pyf --overwrite-signature
 cd ..
 
 python setup.py clean --all
