@@ -6,7 +6,7 @@ python sub_sizes.py
 
 cd ..
 gfortran -E ompgen.F90 -fopenmp -cpp -o omp.f90
-f2py *.f90 -m _wrffortran -h wrffortran.pyf --overwrite-signature
+#f2py *.f90 -m _wrffortran -h wrffortran.pyf --overwrite-signature
 cd ..
 
 python setup.py clean --all
